macro_rules! map_other_error {
($E: expr) => { ... };
}Expand description
map_other_error: convert other error to io:Error and ad file and line info to it.
macro_rules! map_other_error {
($E: expr) => { ... };
}map_other_error: convert other error to io:Error and ad file and line info to it.